@@ -1,5 +1,6 @@
 import logging
-
+import base64
+import urllib.parse
 from django.conf import settings
 from django.http.response import HttpResponse, HttpResponseRedirect
 from django.shortcuts import render, reverse
@@ -10,6 +11,15 @@ import shopify
 from django.contrib.auth import get_user_model
 
 
+def base64_decode(string):
+    """
+    Adds back in the required padding before decoding.
+    """
+    padding = 4 - (len(string) % 4)
+    string = string + ("=" * padding)
+    return base64.urlsafe_b64decode(string)
+
+
 def get_scope_permission(request, myshopify_domain):
     redirect_uri = request.build_absolute_uri(reverse("session_tokens:finalize"))
     myshopify_domain = myshopify_domain.strip()
@@ -18,10 +28,18 @@ def get_scope_permission(request, myshopify_domain):
         getattr(settings, "SHOPIFY_APP_API_VERSION", "unstable"),
     ).create_permission_url(settings.SHOPIFY_APP_API_SCOPE, redirect_uri)
 
+    embedded = request.GET.get("embedded")
+    if not embedded or embedded != "1":
+        return HttpResponseRedirect(permission_url)
+
+    host = request.GET.get("host")
+    if not host:
+        raise Exception("expected host query parameter when embedded=1 is present")
+
     return render(
         request,
         "shopify_auth/iframe_redirect.html",
-        {"shop": myshopify_domain, "redirect_uri": permission_url},
+        {"host": host, "redirect_uri": permission_url},
     )
 
 
@@ -42,6 +60,12 @@ class FinalizeAuthView(View):
         shop = get_user_model().update_or_create(shopify_session, request)
         shop.install(request)
 
+        if host := request.GET.get("host"):
+            decoded_host = base64_decode(host).decode('utf-8')
+            redirect_url = f"https://{decoded_host}/apps/{settings.SHOPIFY_APP_API_KEY}"
+            return HttpResponseRedirect(redirect_url)
+
+
         return HttpResponseRedirect(
             f"https://{myshopify_domain}/admin/apps/{settings.SHOPIFY_APP_API_KEY}"
         )
